@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: aeson-compat
 version: 0.3.2.0
-id: aeson-compat-0.3.2.0-725b78f3168d9bafe282f8360603746a
-key: aeson_BKOlp5ASGYD15xjKUB8zTq
+id: aeson-compat-0.3.2.0-1377f830a9c306c394b4385c9d316f98
+key: aeson_DmMoGnpe6aY79UtFqvnefC
 license: BSD3
 maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
 homepage: https://github.com/phadej/aeson-compat#readme
@@ -20,12 +20,12 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/aeson-compat-0.3.2.0
 library-dirs: /usr/lib/ghc-7.10.3/site-local/aeson-compat-0.3.2.0
 data-dir: /usr/share/arm-linux-ghc-7.10.3/aeson-compat-0.3.2.0
-hs-libraries: HSaeson-compat-0.3.2.0-BKOlp5ASGYD15xjKUB8zTq
+hs-libraries: HSaeson-compat-0.3.2.0-DmMoGnpe6aY79UtFqvnefC
 depends:
     aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
     attoparsec-0.13.0.1-522c252ad233781393fab28c8daf023a
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    base-compat-0.9.0-fa16321d7131a0167d57b06b47b516c7
+    base-compat-0.9.1-b27a2a11ed624cad5ac469eab39183ee
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
